.. include:: ../README.rst

.. toctree::
   :maxdepth: 3

   development.rst
   changes.rst
   license.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

